@@ -1,4 +1,5 @@
 import asyncio
+import inspect
 import urllib
 
 from . import base_server
@@ -63,10 +64,11 @@ class AsyncServer(base_server.BaseServer):
     :param logger: To enable logging set to ``True`` or pass a logger object to
                    use. To disable logging set to ``False``. Note that fatal
                    errors are logged even when ``logger`` is ``False``.
-    :param json: An alternative json module to use for encoding and decoding
-                 packets. Custom json modules must have ``dumps`` and ``loads``
+    :param json: An alternative JSON module to use for encoding and decoding
+                 packets. Custom JSON modules must have ``dumps`` and ``loads``
                  functions that are compatible with the standard library
-                 versions.
+                 versions. This is a process-wide setting, all instantiated
+                 servers and clients must use the same JSON module.
     :param async_handlers: If set to ``True``, run message event handlers in
                            non-blocking threads. To run handlers synchronously,
                            set to ``False``. The default is ``True``.
@@ -212,7 +214,7 @@ class AsyncServer(base_server.BaseServer):
         Note: this method is a coroutine.
         """
         translate_request = self._async['translate_request']
-        if asyncio.iscoroutinefunction(translate_request):
+        if inspect.iscoroutinefunction(translate_request):
             environ = await translate_request(*args, **kwargs)
         else:
             environ = translate_request(*args, **kwargs)
@@ -427,7 +429,7 @@ class AsyncServer(base_server.BaseServer):
     async def _make_response(self, response_dict, environ):
         cors_headers = self._cors_headers(environ)
         make_response = self._async['make_response']
-        if asyncio.iscoroutinefunction(make_response):
+        if inspect.iscoroutinefunction(make_response):
             response = await make_response(
                 response_dict['status'],
                 response_dict['headers'] + cors_headers,
@@ -502,7 +504,7 @@ class AsyncServer(base_server.BaseServer):
         run_async = kwargs.pop('run_async', False)
         ret = None
         if event in self.handlers:
-            if asyncio.iscoroutinefunction(self.handlers[event]):
+            if inspect.iscoroutinefunction(self.handlers[event]):
                 async def run_async_handler():
                     try:
                         try:
